---
layout: template
title: Troubleshooting
permalink: /support/troubleshooting/
link_group: support
---
# Troubleshooting

If you are having problems, have a look at this page. There are currently not
much content here, please submit a PR or write an issue if you want to add or
change something.

### Scanning does not find any devices

Please see [this](../scanning_issues/) page on scanning issues.
